<?php
/**
 * Plugin Name: TextWin.co.il | AI Powered SEO Optimized Content Generator For WP
 * Description: Create High-Quality Content with AI on WP
 * Version: 1.0
 * Author: <a href="https://textwin.co.il/" target=_blank>TextWin.co.il</a>
 */


define( 'textwincoil_PLUGIN_DIR', plugin_dir_path( __FILE__ ) ); 
define( 'textwincoil_PLUGIN_URL', plugin_dir_url( __FILE__ ) );

include_once textwincoil_PLUGIN_DIR . 'inc/textwincoil-api.php';
include_once textwincoil_PLUGIN_DIR . 'inc/textwincoil-html.php';
include_once textwincoil_PLUGIN_DIR . 'inc/textwincoil-generals.php';

 

add_action( 'admin_enqueue_scripts', 'textwincoil_enqueue_admin_styles' );
function textwincoil_enqueue_admin_styles() {

    // Get the current screen object
    $screen = get_current_screen(); 

    // Enqueue styles only on the new post screen and the plugin settings screen
    if ( $screen->id == 'post' || $screen->id == 'settings_page_textwincoil' ) {

        // Enqueue custom admin stylesheet
        wp_enqueue_style( 'textwincoil-admin-styles', textwincoil_PLUGIN_URL . '/css/textwincoil-admin.css?v='.time() );

        // Enqueue Typekit fonts stylesheet
        wp_enqueue_style( 'textwincoil-fonts-1', 'https://use.typekit.net/vyh6fdd.css');
        wp_enqueue_style( 'textwincoil-fonts-2', 'https://fonts.googleapis.com/css2?family=Open+Sans:wght@300;400;500;600;700;800&display=swap');
		
		wp_enqueue_script( 'textwincoil-js', textwincoil_PLUGIN_URL . 'js/textwincoil-js.js?v='.time(), array( 'jquery' ), '1.0.0', true );
		wp_localize_script( 'textwincoil-js', 'textwincoil_ajax_obj', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );

    }

}


function textwincoil_settings_page_render() {
    if (!current_user_can('manage_options')) {
        return;
    }

    $user_credits = textwincoil_get_credits();
    $email = get_option('textwincoil_email');
    $user_token = get_option('textwincoil_user_token');

    if (isset($_POST['email']) && isset($_POST['user_token'])) {
        $email = sanitize_email($_POST['email']);
        $user_token = sanitize_text_field($_POST['user_token']);

        if (!is_email($email)) {
            echo '<div class="error"><p>מייל לא תקין</p></div>';
			delete_option('textwincoil_website_token');
			delete_option('textwincoil_user_token');
			delete_option('textwincoil_email');
            return;
        }

        $website_token = textwincoil_login($email, $user_token);

        if (!$website_token) {
			delete_option('textwincoil_website_token');
			delete_option('textwincoil_user_token');
			delete_option('textwincoil_email');
            echo '<div class="error"><p>ההתחברות נכשלה, בדוק את המייל והאסימון שהזנת.</p></div>';
            return;
        }

        update_option('textwincoil_email', $email);
        update_option('textwincoil_user_token', $user_token);
        update_option('textwincoil_website_token', $website_token);
    }

    $website_token = get_option('textwincoil_website_token');
    $validate_token = textwincoil_validate_token($website_token);
	#print_r($validate_token);
    if ($website_token && !$validate_token) {
        delete_option('textwincoil_website_token');
        delete_option('textwincoil_user_token');
        delete_option('textwincoil_email');
        $website_token = false;
    }
	$user_credits = textwincoil_get_credits();
	
	?>
	<div id="textwincoil-wrapper">
		
		<div class="textwincoil-inner">
			<div class="textwincoil-header">
				<div class="header-logo">
					<a href="https://textwin.co.il/" target="_blank">
						<span class="ia">T</span><span class="io">e</span><span class="ia">x</span><span class="io">t</span><span class="ia">W</span><span class="io">i</span><span class="ia">n</span>
					</a>
				</div>
			</div>
			<div class="side-1">
				<div class="sidebox">
					<div class="wrap">
						<?php if (!$website_token) : ?>
							<h2>כניסה לחשבון TextWin</h2>
							<form method="post">
								<table class="form-table">
									<tbody>
										<tr>
											<th scope="row">
												<label for="email">אימייל</label>
											</th>
											<td>
												<input name="email" type="email" id="email" value="<?php echo esc_attr($email); ?>">
											</td>
										</tr>
										<tr>
											<th scope="row">
												<label for="user_token">אסימון משתמש</label>
											</th>
											<td>
												<div style="position:relative;">
													<input name="user_token" type="text" id="user_token">
													<a href="https://textwin.co.il/dashboard/" target="_blank"><button class="button blue">לחצו לחשיפת אסימון</button></a>
												</div>
											</td>
										</tr>
									</tbody>
								</table>
								<p class="submit">
									<input type="submit" name="submit" id="submit" class="button blue" value="התחברות"/>
								</p>
							</form>
						<?php else : ?> 
							<p>
								התחברת בהצלחה!
								<br /> 
								ניתן לגשת לאשף יצירת המאמרים דרך עמוד יצירת פוסט חדש.
							</p>
							<div class="credit-count">יש לך <span><?php echo esc_html(number_format($user_credits)); ?> קרדיטים</span> <small>1 קרדיט = 1 מילה</small></div>
						<?php endif; ?>
					</div>
				</div>
			</div>
			<div class="side-2">
				<div class="sidebox">
					<div class="textwincoil-menu">
						<div class="textwincoil-menuitem"><a href="https://textwin.co.il/" target="_blank">לאתר הבית של TextWin</a></div>
						<div class="textwincoil-menuitem"><a href="https://textwin.co.il/dashboard/" target="_blank">החשבון שלי</a></div>
						<div class="textwincoil-menuitem"><a href="https://textwin.co.il/dashboard/purchase/" target="_blank">רכישת קרדיטים</a></div>
					</div> 
				</div>
				<div class="cr">
					<img src="https://textwin.co.il/images/raccoon_super.jpg" alt="" class="">
				</div>
			</div>
		</div>
	</div>
	<?php

}


function add_html_to_post_screen() {
	 
	$keywordQuotes = array( "אנחנו מפיקים נושאים לפוסטים, במיוחד בשבילך!", "יצירת נושאים לפוסטים לוקחת זמן, אך שווה את זה.", "התכוננו לגלות נושאים חדשים ומרגשים לפוסטים!", "אל תדאג, אנחנו על זה - הנושאים שלך לפוסטים יהיו מוכנים בקרוב.", "יצירת נושאים לפוסטים היא צורה של אמנות - ואנחנו האמנים!", "אנו מייצרים נושאים מדהימים לפוסטים רק בשבילך - המתינו!", "תהליך יצירת הנושאים לפוסטים מרתק - ואתה עומד לראות מדוע.", "הצוות שלנו עובד בקשה כדי ליצור את הנושאים הטובים ביותר לפוסטים שלך.", "יצירת נושאים לפוסטים היא כמו חפירה אחרי זהב - זה לוקח זמן, אבל התוצאות שוות את זה." );

	$titleQuotes = array( "הכוננו לכמה כותרות מדהימות לפוסטים - אנחנו עובדים על זה!", "יצירת כותרות לפוסטים היא צורה של אמנות - ואנחנו האמנים!", "המצאת כותרות לפוסטים היא אתגר מרגש - ואנחנו מוכנים לו!", "אנחנו מחשבים רעיונות לכותרות מדהימות לפוסטים שלך - המתינו!", "יצירת הכותרת המושלמת לפוסט לוקחת זמן, אבל שווה את זה.", "תהליך המצאת כותרות לפוסטים מרתק - ואתה עומד לראות מדוע.", "אל תדאג, אנחנו עובדים בקשה כדי ליצור את הכותרות הטובות ביותר לפוסטים שלך.", "הכוננו להיפתע מכותרות הפוסטים המדהימות שלנו!", "הצוות שלנו מחויב להמצאת כותרות מעניינות ומושכות תשומת לב עבורך." );

	$tailoringQuotes = array( "אנו מרכיבים משהו ייחודי, רק בשבילך.", "יצירת חוויה מותאמת אישית לוקחת זמן, אך אנחנו עובדים בקשה כדי להפוך את זה למציאות.", "החוויה המותאמת אישית שלך בדרך - התכוננו להתרשם!", "יצירת משהו שמותאם באופן מושלם לך היא העדפה ראשונה שלנו.", "אנחנו יוצרים משהו מיוחד שמותאם לצרכים וההעדפות הייחודיות שלך.", "אל תדאג - אנו עובדים בלתי פוסק כדי ליצור חוויה בלתי נשכחת רק בשבילך.", "התכוננו למשהו שהוא באמת יחיד במינו - זה בדרך!", "יצירת חוויה מותאמת אישית היא תהליך מורכב, אך אנחנו מוכנים לאתגר.", "אנו גאים ליצור משהו שלא רק מותאם אישית לך, אלא גם מצטיין בייחודיותו." );

	$keywordQuotes_quote = $keywordQuotes[rand(0,count($keywordQuotes)-1)];
	
	$titleQuotes_quote = $titleQuotes[rand(0,count($titleQuotes)-1)];
	
	$tailoringQuotes_quote = $tailoringQuotes[rand(0,count($tailoringQuotes)-1)];
	
	
    ?>

	<div id="textwincoil-create">
		
		<div id="textwincoil-progressbar" data-progress="-1" data-progress-label="">
			<div class="textwincoil-progress-inner">
				<div class="textwincoil-progress-inner-bar"></div>
			</div>
		</div>
		
		<div id="textwincoil__creator-form" >
			 
			<input type="hidden" name="textwincoil_post_token" id="textwincoil_post_token" value="" />
			<input type="hidden" name="textwincoil_step_number" id="textwincoil_step_number" value="1" />
			
			<div id="textwincoil__creator" data-step="1" class="loading">


				<?php echo textwincoil_loader_html(); ?>
				
				<div class="creator-topper">
				 
					<a class="loader-text-1" href="https://textwin.co.il/" target=_blank>
						<span class="ia">T</span><span class="io">e</span><span class="ia">x</span><span class="io">t</span><span class="ia">W</span><span class="io">i</span><span class="ia">n</span>
					</a>
					
					<div class="textwincoil-close"><span></span></div>
				
				</div>

				<div class="creator-menu">

					<div class="creator-menu-item active" data-id="1" data-loader="<?php echo $keywordQuotes_quote; ?>" data-next="<?php echo __("בחר מילות מפתח"); ?>" data-prev="">
						<div class="creator-menu-item--label"><?php echo __("פרטים בסיסיים"); ?></div>
						<div class="step-data">
							<div class="step-data-line" data-field="textwincoil_subject" style="display:none;">
								<label><?php echo __("נושא ראשי"); ?></label>
								<span></span>
							</div>
							<div class="step-data-line" data-field="textwincoil_format_type" style="display:none;">
								<label><?php echo __("סוג הפוסט"); ?></label>
								<span></span>
							</div>
							<div class="step-data-line" data-field="textwincoil_length" style="display:none;">
								<label><?php echo __("כמות מילים"); ?></label>
								<span></span>
							</div>
							<div class="step-data-line" data-field="textwincoil_audience" style="display:none;">
								<label><?php echo __("קהל יעד"); ?></label>
								<span></span>
							</div>
							<div class="step-data-line" data-field="textwincoil_purpose" style="display:none;">
								<label><?php echo __("מטרה עיקרית"); ?></label>
								<span></span>
							</div>
							<div class="step-data-line" data-field="textwincoil_tone" style="display:none;">
								<label><?php echo __("טון"); ?></label>
								<span></span>
							</div>
						</div>
					</div>
					<div class="creator-menu-item" data-id="2" data-loader="<?php echo $titleQuotes_quote; ?>" data-next="<?php echo __("בחר כותרת לפוסט"); ?>" data-prev="<?php echo __("עריכת נתונים בסיס"); ?>">
						<div class="creator-menu-item--label"><?php echo __("מילות מפתח"); ?></div>
						<div class="step-data">
							<div class="step-data-line" data-field="textwincoil_keywords" style="display:none;">
								<label><?php echo __("מילות מפתח"); ?></label>
								<span></span>
							</div>
						</div>
					</div>
					<div class="creator-menu-item" data-id="3" data-loader="<?php echo $tailoringQuotes_quote; ?>" data-next="<?php echo __("אישור פרטים"); ?>" data-prev="<?php echo __("עריכת מילות מפתח"); ?>">
						<div class="creator-menu-item--label"><?php echo __("כותרת הפוסט"); ?></div>
						<div class="step-data">
							<div class="step-data-line" data-field="textwincoil_post_title" style="display:none;">
								<label><?php echo __("כותרת הפוסט"); ?></label>
								<span></span>
							</div>
						</div>
					</div> 
					<div class="creator-menu-item" data-id="4" data-loader="<?php echo __("שולח ליצירה"); ?>" data-next="<?php echo __("כן, צור את הפוסט"); ?>" data-prev="<?php echo __("בחירת כותרת מחדש"); ?>">
						<div class="creator-menu-item--label"><?php echo __("אישור פרטים"); ?></div>
						<div class="step-data">
							<div class="step-data-line" data-field="" style="display:none;">
								<label></label>
								<span></span>
							</div>
						</div>
					</div>
					<div class="creator-menu-item" data-id="5" data-prev="" data-next="">
						<div class="creator-menu-item--label"><?php echo __("יצירת פוסט"); ?></div>
						<div class="step-data">
							<div class="step-data-line" data-field="" style="display:none;">
								<label></label>
								<span></span>
							</div>
						</div>
					</div>
					
				</div>

				<div class="creator-steps">

					<div class="creator-steps-inner">

						<div class="creator-step active" data-id="1">

							<h3><?php echo __("פרטים בסיסיים"); ?></h3>
							
							<div class="form-input">
								<label>
									<?php echo __("נושא"); ?> <span class="required"><?php echo __("חובה"); ?></span>
								</label>
								<div class="exp">
									<?php echo __("הזנ/י את הנושא עליו תרצ/י לכתוב."); ?>
									<br/><?php echo __("אנחנו נציע כותרות מתאימות ומילות מפתח לפוסט בנושאים האלה."); ?>
								</div>
								<input type="text" name="textwincoil_subject" id="textwincoil_subject"  value="" />
							</div>
	 
							<div class="form-input">
								<label>
									<?php echo __("סוג הפוסט"); ?> <span class="required"><?php echo __("חובה"); ?></span>
								</label>
								<div class="exp"><?php echo __("סוג הפוסט חשוב מאחר והוא קובע את מבנה הפוסט ואת הסגנון הכללי של הגישה לנושאים המדוברים."); ?></div>
								<select name="textwincoil_format_type" id="textwincoil_format_type"onchange='jQuery(this).parent().find(".miniinfo").text(jQuery(this).find("option:selected").attr("data-info"))'>
									<option value="" disabled selected><?php echo __("בחירת סוג הפוסט..."); ?></option>
									<?php
									$post_types = textwincoil_get_post_types(); 
									foreach ($post_types  as $key => $value) {
										echo '<option value="' . esc_attr($key) . '" data-info="' . esc_attr(__($value['description'],"post-types")) . '">' . esc_attr(__($value['label'],"post-types")) . '</option>';
									} 
									?>
								</select>
								<span class="miniinfo"></span>
							</div>

							<div class="form-input">
								<label>
									<?php echo __("מספר מילים"); ?>
								</label>
								<div class="exp"><?php echo __("כמה מילים תרצה/י שיהיה הפוסט?"); ?></div>
								<input type="number" value="1500" min="250" max="5000" step="250" name="textwincoil_length" id="textwincoil_length" />
							</div>
							
							
							<div class="form-input">
								<label>
									<?php echo __("קהל יעד"); ?>
								</label>
								<div class="exp"><?php echo __("במילים פשוטות, מי קהל היעד שלך?"); ?></div>
								<input type="text" name="textwincoil_audience" id="textwincoil_audience" placeholder="<?php echo __("אפשר להכניס טווח גילאים, תחומי עניין או כלום"); ?>" value="" />
							</div>
							
							<div class="form-input">
								<label>
									<?php echo __("מטרה עיקרית"); ?>
								</label>
								<div class="exp"><?php echo __("במילים פשוטות, מה מטרת הפוסט שלך?"); ?></div>
								<input type="text" name="textwincoil_purpose" id="textwincoil_purpose" placeholder="<?php echo __("למכור שירות, לתת מידע על משהו או פשוט כלום"); ?>" value="" />
							</div>
							 
							<div class="form-input">
								<label>
									<?php echo __("טון"); ?>
								</label>
								<div class="exp"><?php echo __("בחירת טון כתיבה"); ?></div>
								 
								<select name="textwincoil_tone" id="textwincoil_tone" onchange='$(this).parent().find(".miniinfo").text($(this).find("option:selected").attr("data-info"))'>
									<option value="" disabled selected><?php echo __("בחר טון", "tones", 1); ?></option>
									<optgroup label="<?php echo __("כללי", "tones", 1); ?>">
										<option value="informative" data-info="<?php echo __("נייטרלי ומפורט", "tones", 1); ?>"><?php echo __("מפורט", "tones", 1); ?></option>
										<option value="friendly" data-info="<?php echo __("קז'ואלי ושיחתי", "tones", 1); ?>"><?php echo __("חברותי", "tones", 1); ?></option>
										<option value="authoritative" data-info="<?php echo __("מאובטח ומשכיל", "tones", 1); ?>"><?php echo __("רשמי", "tones", 1); ?></option>
										<option value="thoughtful" data-info="<?php echo __("מעייני וממומחש", "tones", 1); ?>"><?php echo __("מחשבתי", "tones", 1); ?></option>
									</optgroup>
									<optgroup label="<?php echo __("קז'ואלי", "tones", 1); ?>">
										<option value="inviting" data-info="<?php echo __("חברותי ומזמין", "tones", 1); ?>"><?php echo __("מזמין", "tones", 1); ?></option>
										<option value="direct" data-info="<?php echo __("פשוט וישיר", "tones", 1); ?>"><?php echo __("ישיר", "tones", 1); ?></option>
										<option value="gentle" data-info="<?php echo __("שקט ועדין", "tones", 1); ?>"><?php echo __("עדין", "tones", 1); ?></option>
										<option value="curious" data-info="<?php echo __("סקרן ושואל", "tones", 1); ?>"><?php echo __("סקרן", "tones", 1); ?></option>
										<option value="relaxed" data-info="<?php echo __("רגוע ומשוחרר", "tones", 1); ?>"><?php echo __("רגוע", "tones", 1); ?></option>
									</optgroup>
									<optgroup label="<?php echo __("מפורט", "tones", 1); ?>">
										<option value="descriptive" data-info="<?php echo __("מפורט ותיאורי", "tones", 1); ?>"><?php echo __("תיאורי", "tones", 1); ?></option>
										<option value="concise" data-info="<?php echo __("חד ומקוצר", "tones", 1); ?>"><?php echo __("מקוצר", "tones", 1); ?></option>
									</optgroup>
									<optgroup label="<?php echo __("מקצועי", "tones", 1); ?>">
										<option value="business-like" data-info="<?php echo __("רשמי ורציני", "tones", 1); ?>"><?php echo __("עסקי", "tones", 1); ?></option>
										<option value="technical" data-info="<?php echo __("מדויק וטכני", "tones", 1); ?>"><?php echo __("טכני", "tones", 1); ?></option>
										<option value="polished" data-info="<?php echo __("מלוטש ומתוחכם", "tones", 1); ?>"><?php echo __("מלוטש", "tones", 1); ?></option>
									</optgroup>
									<optgroup label="<?php echo __("שכנעני", "tones", 1); ?>">
										<option value="respectful" data-info="<?php echo __("מנומס ועצמאי", "tones", 1); ?>"><?php echo __("מכבד", "tones", 1); ?></option>
										<option value="persuasive" data-info="<?php echo __("חזק ומשכנע", "tones", 1); ?>"><?php echo __("משכנע", "tones", 1); ?></option>
										<option value="motivational" data-info="<?php echo __("מעודד ומעורר השראה", "tones", 1); ?>"><?php echo __("מניע", "tones", 1); ?></option>
									</optgroup>
									<optgroup label="רגשי">
										<option value="excited" data-info="<?php echo __("נלהב ואנרגטי", "tones", 1); ?>"><?php echo __("מתרגש", "tones", 1); ?></option>
										<option value="optimistic" data-info="<?php echo __("חיובי ומקווה", "tones", 1); ?>"><?php echo __("אופטימי", "tones", 1); ?></option>
										<option value="skeptical" data-info="<?php echo __("ספקן וביקורתי", "tones", 1); ?>"><?php echo __("ספקן", "tones", 1); ?></option>
										<option value="determined" data-info="<?php echo __("נחוש וממוקד", "tones", 1); ?>"><?php echo __("נחוש", "tones", 1); ?></option>
										<option value="humorous" data-info="<?php echo __("קליל ומצחיק", "tones", 1); ?>"><?php echo __("הומוריסטי", "tones", 1); ?></option>
									</optgroup>
								</select> 
								<span class="miniinfo"></span>
							</div>
							 
							
						</div> 

						<div class="creator-step" data-id="2">
							
							<h3><?php echo __("מילות מפתח"); ?></h3>
							
							<div class="form-input" id="textwincoil_keywords_container">
								<label>
									<?php echo __("מילות מפתח מומלצות"); ?>
								</label>
								<div class="exp">
									<?php echo __("בחר/י מילות מפתח מהרשימה שלמטה או הזנ/י משלך."); ?>
								</div>
								<div class="post-keywords">
								
								</div>
								 
								<h4><?php echo __("מילות מפתח נוספות"); ?></h4>
								<input type="text" name="textwincoil_manual_keywords" id="textwincoil_manual_keywords"  value="" placeholder="<?php echo __("נקודת מפתח 1, נקודת מפתח 2 ..."); ?>" />
							</div>
							
						</div>
						
						<div class="creator-step" data-id="3">

							<h3><?php echo __("כותרת הפוסט"); ?></h3>

							<div class="form-input">
								<div class="exp">
									<?php echo __("השתמש/י בכותרת פוסט משלך או בחר/י אחת מאלו שלמטה."); ?>
								</div>
								<input type="text" name="textwincoil_post_title" id="textwincoil_post_title"  value="" />
								
								<h4>
									<span><?php echo __("ההמלצות שלנו"); ?></span>
									<div class="autogen-button"><i class="fa-regular fa-wand-magic-sparkles"></i><?php echo __("צור המלצות מחדש"); ?></div>
								</h4>
								
								<div class="post-ideas">
								
								</div>
							</div>
							
						</div> 

						<div class="creator-step" data-id="4">
							
							<h3><?php echo __("אשר/י את פרטי הפוסט"); ?></h3> 
							
							<p><?php echo __("לפנייך תצוגה מקדימה של מבנה הפוסט לפני היצירה."); ?></p> 
							<p><?php echo __("ברגע שתאשר/י, תהליך היצירה ייקח כ-2 דקות."); ?></p>
							<p><?php echo __("השאירו את החלון פתוח וברגע שהפוסט יהיה מוכן תועברו אוטומטית לעריכה שלו."); ?></p>
							
							<div id="textwincoil_page-sections">
								
								<div id="textwincoil_post_structure_title"></div>
								<div id="textwincoil_post_structure_intro"></div>
								<div id="textwincoil_post_structure_sections"></div>
								
							</div>
							
						</div>


						<div class="creator-step active" data-id="5">
							<div class="step-center" style="">	 
								
								<img src="/images/raccoon_delivery.jpg" class="delivery-raccoon" style="">
								<p class="">
									"<strong class="post_name">{{post_title}}</strong>"
									<br/><?php echo __("כעת בתהליך יצירה ויסתיים בקרוב."); ?>
								</p>
								
								<div class="youmayleave">
									<div>
										<?php echo __("אפשר לעזוב את העמוד כעת או להמתין שהיצירה תסתיים."); ?><br/><br/><?php echo __("ברגע שהיא תסתיים, תעברו למסך העריכה של הפוסט החדש."); ?>
									</div>
								</div>
								 
 
							</div>
						</div>


					</div>


					<div class="creator-steps-bottom">

						<div class="step-back" style="display:none;"  onclick='textwincoil__go_to_step(-1)'><i class="fa-sharp fa-solid fa-arrow-left"></i><span><?php echo __("הקודם"); ?></span></div>
						<div class="step-next"><span><?php echo __("בחירת מילות מפתח"); ?></span><i class="fa-regular fa-arrow-right"></i></div>

					</div>

				</div> 

			</div>
		
		</div>
			
		 
	</div>
	  
	<div id="textwincoil-error-popup">
		<div class="textwincoil-error-popup--inner">

			<div class="textwincoil-error-popup--close">X</div>
			<div class="textwincoil-error-popup--msg"><span></span><br/>רכוש קרדיטים או הזן מספר מילים נמוך יותר כדי להמשיך.</div>
			<div class="textwincoil-error-popup--buttons">
				<a href="https://textwin.co.il/dashboard/credits/" target=_blank><button class="textwincoil-button button">רכישת קרדיטים</button></a>
			</div>

		</div>

	</div>

	<?php
}
add_action( 'admin_footer-post-new.php', 'add_html_to_post_screen' );


// Add top priority meta box to post edit screen
function textwincoil_add_meta_box() {
    add_meta_box(
        'textwincoil_add_meta_box',
        'TextWin',
        'textwincoil_meta_box_callback',
        'post',
        'side',
        'high'
    );
}
add_action( 'add_meta_boxes', 'textwincoil_add_meta_box' );

// Callback function to display top priority meta box
function textwincoil_meta_box_callback( $post ) {
    textwincoil_form_element();
}


